@@ -1,8 +1,8 @@
-import json
 import logging
 
-from isc_common import setAttr
+from isc_common import setAttr, delAttr
 from isc_common.http.RPCRequest import RPCRequest
+from isc_common.json import BytesToJson
 
 logger = logging.getLogger(__name__)
 
@@ -55,33 +55,61 @@ class DSRequest(RPCRequest):
     def __init__(self, request):
         from isc_common.auth.models.user import User
 
-        self.username = request.session._session.get('username')
-        self.user_id = request.session._session.get('user_id')
+        self.json = None
 
-        try:
-            if self.user_id == None and request.GET.get('ws_channel') != None:
-                self.user_id = User.objects.get(username=request.GET.get('ws_channel').split('_')[1]).id
-            if self.user_id != None:
-                self.user = User.objects.get(id=self.user_id)
-            else:
-                self.user = None
-        except User.DoesNotExist:
+        if request != None and request.body != b'':
+            self.json = BytesToJson(request.body)
+
+            data = self.json.get('data')
             self.user = None
-        self.is_admin = request.session._session.get('is_admin')
-        self.is_develop = request.session._session.get('is_develop')
-        self.ws_channel = request.session._session.get('ws_channel')
-        self.ws_port = request.session._session.get('ws_port')
-        self.host = request.session._session.get('host')
+            if isinstance(data, dict):
+                httpHeaders = data.get('httpHeaders')
+                if isinstance(httpHeaders, dict):
+                    if httpHeaders.get('WS_CHANNEL') != None:
+                        self.ws_channel = httpHeaders.get('WS_CHANNEL')
 
-        if request and isinstance(request.body, bytes):
-            try:
-                bodyStr = request.body.decode("utf-8")
-                self.json = json.loads(bodyStr)
+                    if httpHeaders.get('WS_PORT') != None:
+                        self.ws_port = httpHeaders.get('WS_PORT')
 
-            except:
-                self.json = None
+                    if httpHeaders.get('HOST') != None:
+                        self.host = httpHeaders.get('HOST')
 
-            RPCRequest.__init__(self, self.json)
+                    if httpHeaders.get('USERNAME') != None:
+                        self.username = httpHeaders.get('USERNAME')
+
+                    if httpHeaders.get('USER_ID') != None:
+                        # print(f'''USER_ID: {httpHeaders.get('USER_ID')}''')
+                        self.user_id = httpHeaders.get('USER_ID')
+                        self.user = User.objects.get(id=self.user_id)
+
+                    if httpHeaders.get('IS_ADMIN') != None:
+                        self.is_admin = httpHeaders.get('IS_ADMIN')
+
+                    if httpHeaders.get('IS_DEVELOP') != None:
+                        self.is_develop = httpHeaders.get('IS_DEVELOP')
+
+                    delAttr(self.json.get('data'), 'httpHeaders')
+
+            if self.user == None:
+                self.username = request.session._session.get('username')
+                self.user_id = request.session._session.get('user_id')
+
+                try:
+                    if self.user_id == None and request.GET.get('ws_channel') != None:
+                        self.user_id = User.objects.get(username=request.GET.get('ws_channel').split('_')[1]).id
+                    if self.user_id != None:
+                        self.user = User.objects.get(id=self.user_id)
+                    else:
+                        self.user = None
+                except User.DoesNotExist:
+                    self.user = None
+                self.is_admin = request.session._session.get('is_admin')
+                self.is_develop = request.session._session.get('is_develop')
+                self.ws_channel = request.session._session.get('ws_channel')
+                self.ws_port = request.session._session.get('ws_port')
+                self.host = request.session._session.get('host')
+
+        RPCRequest.__init__(self, self.json)
 
     def get_data(self, excluded_keys=['grid']):
         res = None
