@@ -761,10 +761,12 @@ class CommonManager(Manager):
             field = field[0]
 
         if field:
-            if field.null:
+            # if field.null:
+            if field == None:
                 setAttr(_data, 'id', None)
                 res = _data
             else:
+                _data = {k: v for k, v in _data.items() if v is not None}
                 res = field.related_model.objects.filter(**_data)
                 if len(res) >= 1:
                     res = res[0]
